<?php
/**
 *
 *   Hepsipay adına Alttantire Yazılım Çözümleri tarafından geliştirilmiştir.
 *
 * @author      Alttantire <info@alttantire.com>
 * @date        2025
 *
 */

if ( ! defined( '_PS_VERSION_' ) ) {
	exit;
}

if ( ! defined( "ALTTANTIRE_MIN_PHP_VER" ) ) {
	define( 'ALTTANTIRE_MIN_PHP_VER', '5.6.0' );
}

use Alttantire\HepsipayGateway;

include_once _PS_MODULE_DIR_ . 'hepsipay/lib/HepsipayGateway.php';

class HelperModel {
	/**
	 * Girilen api bilgilerinin doğruluğunu teyit eder.
	 */
	public static function checkCredential( $posted, $context ) {
		$gateway = new HepsiPayGateway(
			$posted['hepsipay_vpos_environment'],
			$posted['hepsipay_vpos_merchant_no'],
			$posted['hepsipay_vpos_terminal_no'],
			$posted['hepsipay_vpos_store_key']
		);

		$gateway->set_amount( 100 );
		$gateway->set_account_key( "905551234567" );

		$return_url = $context->link->getModuleLink( 'hepsipay', 'payment', array(),
			Configuration::get( 'PS_SSL_ENABLED' ) );

		$gateway->set_merchant_callback_url(
			$return_url
		);

		$gateway->set_merchant_order_number( 1 );
		$gateway->set_is_guest_user( true );
		$gateway->set_force_3ds( true );
		$gateway->set_allowed_installments( [ 1 ] );
		$gateway->set_frame_type( 1 );
		$gateway->set_basket_item( [
			"Product"                => "Credential Check",
			"Price"                  => 100,
			"SubMerchantMemberId"    => null,
			"SubMerchantMemberPrice" => null,
			"CategoryId"             => null,
			"ExternalId"             => null,
		] );

		try {
			// Check Availability
			$frame_check_availability_response = $gateway->check_availability();

			if ( $frame_check_availability_response->Success === true ) {
				$frame_init_response = $gateway->frame_init();
				if ( $frame_init_response && $frame_init_response->Success === true ) {
					return true;
				} else {
					throw new \InvalidArgumentException( $frame_init_response->Message );
				}
			} else {
				throw new \InvalidArgumentException( $frame_check_availability_response->Message );
			}
		} catch ( \Exception $e ) {
			return $e->getMessage();
		}
	}

	/**
	 * Sistem bilgi box içeriğini doldurma işlemi
	 */
	public static function renderSystemInfo() {
		$module = Module::getInstanceByName( 'hepsipay' );

		$data = [
			"prestashop"        => defined( '_PS_VERSION_' ) ? _PS_VERSION_ : "N/A",
			"hepsipay_plugin"   => $module->version,
			"php_compatibility" => version_compare( phpversion(), ALTTANTIRE_MIN_PHP_VER, '>=' ),
			"php_version"       => phpversion(),
			"curl"              => function_exists( 'curl_init' ),
			"file_get_contents" => function_exists( 'file_get_contents' ) && ini_get( 'allow_url_fopen' ),
		];

		$output = '<div class="row">';

		$output .= '   <div class="col-sm-2">';
		$output .= '      <div class=" alert-success" style="padding: 8px" role="alert">';
		$output .= 'Hepsipay Plugin v' . $data["hepsipay_plugin"];
		$output .= '      </div>';
		$output .= '   </div>';

		$output .= '   <div class="col-sm-2">';
		$output .= '      <div class=" alert-success" style="padding: 8px" role="alert">';
		$output .= 'Prestashop v' . $data["prestashop"];
		$output .= '      </div>';
		$output .= '   </div>';

		$output .= '   <div class="col-sm-2">';
		$output .= '      <div class="' . ( $data["php_compatibility"] ? 'alert-success' : 'alert-warning' ) . '" style="padding: 8px" role="alert">';
		$output .= 'PHP v' . $data["php_version"];
		$output .= '      </div>';
		$output .= '   </div>';

		$output .= '   <div class="col-sm-2">';
		$output .= '      <div class="' . ( $data["curl"] ? 'alert-success' : 'alert-warning' ) . '" style="padding: 8px" role="alert">';
		$output .= 'curl';
		$output .= '      </div>';
		$output .= '   </div>';

		$output .= '   <div class="col-sm-2">';
		$output .= '      <div class="' . ( $data["file_get_contents"] ? 'alert-success' : 'alert-warning' ) . '" style="padding: 8px" role="alert">';
		$output .= 'fopen';
		$output .= '      </div>';
		$output .= '   </div>';

		$output .= '</div>';

		return $output;

	}

}
